<?php

/**
 * Copyright © 2019-present Simplr Solutions Inc. All rights reserved
 */

namespace Simplr\SimplrExtension\Api;

use Magento\Sales\Api\Data\OrderInterface as Order;
use Magento\Sales\Api\Data\OrderSearchResultInterface as OrderSearchResult;
use Magento\Framework\Api\SearchCriteriaInterface as SearchCriteria;
use Magento\Sales\Api\Data\CreditmemoCommentCreationInterface as CreditmemoCommentCreation;
use Magento\Sales\Api\Data\CreditmemoCreationArgumentsInterface as CreditmemoCreationArgument;
use Magento\Sales\Api\Data\CreditmemoItemCreationInterface as CreditmemoItemCreation;

/**
 * @api
 */
interface SimplrAPIInterface
{
    /**
     * Returns list of orders by search criteria
     *
     * @param SearchCriteria $searchCriteria The search criteria.
     * @return OrderSearchResult Order search result interface.
     */
    public function getOrdersAPI(SearchCriteria $searchCriteria);
    
    /**
     * Returns order info by id
     *
     * @param int $orderId The order orderId.
     * @return Order
     */
    public function getOrderAPI($orderId);
    
    /**
     * Cancel order by id
     *
     * @param int $orderId The order orderId.
     * @return Order
     */
    public function cancelOrderAPI($orderId);

    /**
     * Refund items of the order
     *
     * @param int $orderId
     * @param CreditmemoItemCreation[] $items
     * @param bool|null $notify
     * @param bool|null $appendComment
     * @param CreditmemoCommentCreation|null $comment
     * @param CreditmemoCreationArgument|null $arguments
     * @return Order
     */
    public function refundOrderAPI(
        $orderId,
        array $items = [],
        $notify = false,
        $appendComment = false,
        CreditmemoCommentCreation $comment = null,
        CreditmemoCreationArgument $arguments = null
    );

    /**
     * Returns extension version
     *
     * @return string
     */
    public function versionAPI();
}
